#!/usr/bin/python
# -*- coding: utf-8 -*-

import globdef as G
from PyQt5 import QtGui, QtCore, QtWidgets


# Base class for the two matrix windows.
#
class Matrixwin (QtWidgets.QWidget):
    
    def __init__(self, parent, nrow, ncol): 
        super (Matrixwin, self).__init__(parent)
        self.nrow = nrow
        self.ncol = ncol
        self.xs = ncol * (G.ELM_XS + 1) + 1
        self.ys = nrow * (G.ELM_YS + 1) + 1
        self.resize (self.xs, self.ys)


    def paintEvent(self, E):
        qp = QtGui.QPainter(self)
        qp.setRenderHint (QtGui.QPainter.Antialiasing)
        qp.setBrush (QtCore.Qt.NoBrush)
        qp.setPen (QtGui.QPen (QtGui.QColor (G.MK_N), 0.2))
        qp.translate (0.5, 0.5)
        x = 0
        for i in range (self.ncol + 1):
            qp.drawLine (x, 0, x, self.ys)
            x += G.ELM_XS + 1
        y = 0
        for i in range (self.nrow + 1):
            qp.drawLine (0, y, self.xs, y)
            y += G.ELM_YS + 1
    



#!/usr/bin/python
# -*- coding: utf-8 -*-

import sys
import signal
import globdef
from PyQt5 import QtWidgets
from jacktools.jackmatrix import JackMatrix
from mainwin import Mainwindow


# Define input and output port names.
#
inputs = [ '1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12' ]
outputs = [ 'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H' ]
jackname = 'Matrix'


# Create the JackMatrix.
#
jmatrix = JackMatrix (len (inputs), len (outputs), 0.1, jackname)


# Connect inputs and outputs.
#
#jmat.connect_input (0, '...')
#jmat.connect_input (1, '...')
#
#jmat.connect_output (0, '...')
#jmat.connect_output (1, '...')


# Start PyQt5 app.
#
signal.signal (signal.SIGINT, signal.SIG_DFL)
app = QtWidgets.QApplication (sys.argv)
globdef.darkpal (app)
Mainwindow (inputs, outputs, jmatrix, jackname)
sys.exit (app.exec_())


